==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ADefaultCaseLabel.h <==
// public final class soot.jimple.parser.node.ADefaultCaseLabel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2508ec7083cc21e2 soot_jimple_parser_node_ADefaultCaseLabel
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 4c191822f0fe0fe5 soot_jimple_parser_node_PCaseLabel

// header file dependencies
// @dep_header soot_jimple_parser_node_PCaseLabel

#include "soot/jimple/parser/node/PCaseLabel.h"

#ifndef _JC_soot_jimple_parser_node_ADefaultCaseLabel_H_
#define _JC_soot_jimple_parser_node_ADefaultCaseLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDefault$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$refs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$refs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object	_jc_soot_jimple_parser_node_ADefaultCaseLabel$object;

typedef const struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *);
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$_init$24f9ac7608461d12(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_TDefault$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADefaultCaseLabel$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *);
extern struct _jc_soot_jimple_parser_node_TDefault$object *_jc_soot_jimple_parser_node_ADefaultCaseLabel$method$getDefault$4afe79b49c16d074(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *);
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$setDefault$19b86206783b2b9a(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_TDefault$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADefaultCaseLabel$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$getDefault$4afe79b49c16d074;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$setDefault$19b86206783b2b9a;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *);
	struct _jc_soot_jimple_parser_node_TDefault$object	*(*getDefault$4afe79b49c16d074)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setDefault$19b86206783b2b9a)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_TDefault$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PCaseLabel$vmethods	soot_jimple_parser_node_PCaseLabel;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods	soot_jimple_parser_node_ADefaultCaseLabel;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs {
	struct _jc_soot_jimple_parser_node_TDefault$object	*__5fdefault__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$refs {
    _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs	soot_jimple_parser_node_ADefaultCaseLabel;
    _jc_soot_jimple_parser_node_PCaseLabel$sub_refs	soot_jimple_parser_node_PCaseLabel;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs	soot_jimple_parser_node_PCaseLabel;
    _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs	soot_jimple_parser_node_ADefaultCaseLabel;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object {
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype _jc_soot_jimple_parser_node_ADefaultCaseLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADefaultCaseLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADefaultCaseLabel$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADefaultCaseLabel_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ADefaultCaseLabel.h <==
// public final class soot.jimple.parser.node.ADefaultCaseLabel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2508ec7083cc21e2 soot_jimple_parser_node_ADefaultCaseLabel
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 4c191822f0fe0fe5 soot_jimple_parser_node_PCaseLabel

// header file dependencies
// @dep_header soot_jimple_parser_node_PCaseLabel

#include "soot/jimple/parser/node/PCaseLabel.h"

#ifndef _JC_soot_jimple_parser_node_ADefaultCaseLabel_H_
#define _JC_soot_jimple_parser_node_ADefaultCaseLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDefault$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$refs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$refs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs	_jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object	_jc_soot_jimple_parser_node_ADefaultCaseLabel$object;

typedef const struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$_init$24f9ac7608461d12(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_TDefault$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADefaultCaseLabel$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TDefault$object *_jc_soot_jimple_parser_node_ADefaultCaseLabel$method$getDefault$4afe79b49c16d074(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADefaultCaseLabel$method$setDefault$19b86206783b2b9a(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_TDefault$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADefaultCaseLabel$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$getDefault$4afe79b49c16d074;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$setDefault$19b86206783b2b9a;
extern _jc_method _jc_soot_jimple_parser_node_ADefaultCaseLabel$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TDefault$object	*(*getDefault$4afe79b49c16d074)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setDefault$19b86206783b2b9a)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *, struct _jc_soot_jimple_parser_node_TDefault$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PCaseLabel$vmethods	soot_jimple_parser_node_PCaseLabel;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vmethods	soot_jimple_parser_node_ADefaultCaseLabel;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs {
	struct _jc_soot_jimple_parser_node_TDefault$object	*__5fdefault__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$refs {
    _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_refs	soot_jimple_parser_node_ADefaultCaseLabel;
    _jc_soot_jimple_parser_node_PCaseLabel$sub_refs	soot_jimple_parser_node_PCaseLabel;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs	soot_jimple_parser_node_PCaseLabel;
    _jc_soot_jimple_parser_node_ADefaultCaseLabel$sub_nonrefs	soot_jimple_parser_node_ADefaultCaseLabel;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADefaultCaseLabel$object {
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADefaultCaseLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADefaultCaseLabel$vtype _jc_soot_jimple_parser_node_ADefaultCaseLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADefaultCaseLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADefaultCaseLabel$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADefaultCaseLabel_H_ */
